@@ -2,13 +2,17 @@ import logging
 
 from rasa_sdk import utils
 from rasa_sdk.endpoint import create_argument_parser, run
+from rasa_sdk.constants import APPLICATION_ROOT_LOGGER_NAME
 
 
 def main_from_args(args):
-    logging.basicConfig(level=logging.DEBUG)
+    """Run with arguments."""
     logging.getLogger("matplotlib").setLevel(logging.WARN)
 
     utils.configure_colored_logging(args.loglevel)
+    utils.configure_file_logging(
+        logging.getLogger(APPLICATION_ROOT_LOGGER_NAME), args.log_file, args.loglevel
+    )
     utils.update_sanic_log_level()
 
     run(
